Index: chrome/browser/ui/browser_dialogs.h |
diff --git a/chrome/browser/ui/browser_dialogs.h b/chrome/browser/ui/browser_dialogs.h |
index 45fa64a69177b13e4d310a109c96dc4cec23c6e3..74351a4f6cce1ef30feb9d3135ffc938bf6949c9 100644 |
--- a/chrome/browser/ui/browser_dialogs.h |
+++ b/chrome/browser/ui/browser_dialogs.h |
@@ -117,8 +117,8 @@ content::ColorChooser* ShowColorChooser(content::WebContents* web_contents, |
#if defined(OS_MACOSX) |
-// Shows a Views website settings bubble at the given anchor point. |
-void ShowWebsiteSettingsBubbleViewsAtPoint( |
+// Shows a Views page info bubble at the given anchor point. |
+void ShowPageInfoBubbleViewsAtPoint( |
const gfx::Point& anchor_point, |
Profile* profile, |
content::WebContents* web_contents, |